BadgeClient class abstract
Interface to the Badges resource
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
list(
{DateTime? date, int? limit, String? eTag}) → Future< CacheableResource< List< >BadgeModel> > -
Get the user's badges for a specified
date. Alimitmay be set on the maximum number of badges to be returned. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited