IntegrationClient class abstract

Interface for the Integration resource

Constructors

IntegrationClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String identifier, String redirectUri) Future<IntegrationConnectedModel>
Gets the authorize URL for the given identifier.
disconnect(String identifier) Future<void>
Disconnects the integration with the given identifier. The current user will no longer have fitness data sent to the NxFit service.
getIntegration(String identifier, {String? eTag, DateTime? ifModifiedSince}) Future<CacheableResource<IntegrationModel>>
Fetches the integration for the given identifier.
listIntegrations({String? eTag, DateTime? ifModifiedSince}) Future<CacheableResource<List<IntegrationModel>>>
Fetches all integrations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited