connect abstract method
Gets the authorize URL for the given identifier.
Generates a URL to be used to launch the user through the integration authorize process. Part of the URL includes a redirect URL which is used to send the result of the authorize process back to your app. The redirect url contains the application package ID of the app initiating the authorize process. This is done to ensure that the application initiating the authorize process receives the result from the browser. An IntentFilter is required to make this work.
Implementation
Future<IntegrationConnectedModel> connect(String identifier, String redirectUri);