getIntegration abstract method

Future<CacheableResource<IntegrationModel>> getIntegration(
  1. String identifier, {
  2. String? eTag,
  3. DateTime? ifModifiedSince,
})

Fetches the integration for the given identifier.

This call supports change detection, however setting both the ifModifiedSince and eTag to null will always fetch the current resource. If both are set, ifModifiedSince takes precedence.

Returns a IntegrationModel as a CacheableResource.

Throws NotModifiedException if no change was detected.

Implementation

Future<CacheableResource<IntegrationModel>> getIntegration(String identifier, {String? eTag, DateTime? ifModifiedSince});