listIntegrations abstract method

Future<CacheableResource<List<IntegrationModel>>> listIntegrations({
  1. String? eTag,
  2. DateTime? ifModifiedSince,
})

Fetches all integrations.

This call supports change detection, however setting both the ifModifiedSince and eTag to null will always fetch the current resource. If both are set, ifModifiedSince takes precedence.

Returns a List&lt;IntegrationModel&gt; as a CacheableResource.

Throws NotModifiedException if no change was detected.

Implementation

Future<CacheableResource<List<IntegrationModel>>> listIntegrations({String? eTag, DateTime? ifModifiedSince});