LocalIntegrationClient class abstract

Constructors

LocalIntegrationClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
isReady Stream<bool>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

connect(String integrationIdentifier) Future<void>
disconnect(String integrationIdentifier) Future<void>
getIntegrations() Future<List<LocalIntegration>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited