ProfileClient class abstract

Interface to the Profile resource

Constructors

ProfileClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteImage() Future<void>
Will delete the user's current profile image from storage and set the default image as the user's profile image.
getPersonalProfile({DateTime? ifModifiedSince, String? eTag}) Future<CacheableResource<PersonalProfileModel>>
Get the profile of the currently authenticated user. This call supports change detection, however setting both the ifModifiedSince and eTag to null will always fetch the current resource. If both are set, ifModifiedSince takes precedence.
getPublicProfile(int userId, {DateTime? ifModifiedSince, String? eTag}) Future<CacheableResource<PublicProfileModel>>
Get the public profile of a particular user.
getSettings({DateTime? ifModifiedSince, String? eTag}) Future<CacheableResource<ProfileSettingsModel>>
Fetches the current user settings. This call supports change detection, however setting both the ifModifiedSince and eTag to null will always fetch the current resource. If both are set, ifModifiedSince takes precedence.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(String emailAddress, String givenName, String familyName, String imageUrl, LocalDate dateOfBirth) Future<void>
Update the user's profile. Not all properties in the ProfileModel can be updated, so this method accepts only parameters that can be updated.
updateImage(Uint8List imageBytes) Future<void>
Will upload an image file in Uint8List format to the server and make it the current profile image for the current user. The file must be in one of the following formats: PNG, JPG, WEBP.
updateSettings(SessionPrivacy defaultSessionPrivacy, int? primaryLocationId) Future<void>
Updates the current user settings.

Operators

operator ==(Object other) bool
The equality operator.
inherited