deleteImage abstract method
Will delete the user's current profile image from storage and set the default image as the user's profile image.
Implementation
Future<void> deleteImage();
Will delete the user's current profile image from storage and set the default image as the user's profile image.
Future<void> deleteImage();