getPersonalProfile abstract method

Future<CacheableResource<PersonalProfileModel>> getPersonalProfile({
  1. DateTime? ifModifiedSince,
  2. String? eTag,
})

Get the profile of the currently authenticated user. This call supports change detection, however setting both the ifModifiedSince and eTag to null will always fetch the current resource. If both are set, ifModifiedSince takes precedence.

Returns a PersonalProfileModel as a CacheableResource.

Throws NotModifiedException if no change was detected.

Implementation

Future<CacheableResource<PersonalProfileModel>> getPersonalProfile({ DateTime? ifModifiedSince, String? eTag });