updateImage abstract method

Future<void> updateImage(
  1. Uint8List imageBytes
)

Will upload an image file in Uint8List format to the server and make it the current profile image for the current user. The file must be in one of the following formats: PNG, JPG, WEBP.

Implementation

Future<void> updateImage(Uint8List imageBytes);