getForUser abstract method

Future<CacheableResource<UserSessionModel>> getForUser(
  1. int userId,
  2. int id, {
  3. DateTime? ifModifiedSince,
  4. String? eTag,
})

Get the public version of a session for the given ID. This is a helper method for some of the other overloads to assist with the cache control parameters. It accepts both

@param id The unique session identifier @param ifModifiedSince Used for change detection. In subsequent calls set this to the value of the lastModifiedOn property of the CacheableResource. @param eTag Used for change detection. In subsequent calls set this to the value of the eTag property of the CacheableResource. @return A UserSessionModel as a CacheableResource @throws NotModifiedException

Implementation

//  ifModifiedSince and eTag. If both are provided it will favour ifModifiedSince.
///
/// @param id The unique session identifier
/// @param ifModifiedSince Used for change detection. In subsequent calls set this to the value of the lastModifiedOn property of the CacheableResource.
/// @param eTag Used for change detection. In subsequent calls set this to the value of the eTag property of the CacheableResource.
/// @return A [UserSessionModel] as a [CacheableResource]
/// @throws NotModifiedException
Future<CacheableResource<UserSessionModel>> getForUser(int userId, int id, {DateTime? ifModifiedSince, String? eTag});