list abstract method
Retrieve a list of sessions with a start date between the from and to dates, inclusive. The maximum difference between the from and to dates is 31 days.
If no from date is specified the start of the current day is used. The from value MUST be lesser than the to parameter. If no to date is
specified the end of the current day is used. The to value MUST be greater than the from parameter.
eTag is Used for change detection. A NULL eTag will always fetch the current resource. In subsequent calls set this to the value of the
eTag property of the CacheableResource.
Returns a UserSessionModel as a CacheableResource.
Throws NotModifiedException
Implementation
Future<CacheableResource<List<UserSessionModel>>> list({DateTime? from, DateTime? to, String? eTag});