listForCohort abstract method
- DateTime from,
- DateTime to,
- Studio studio, {
- String? etag,
- PaginationRequest? pagination,
Retrieve a list of sessions with a start date between the from and to dates, inclusive. The maximum difference between the from and to dates is 31 days.
@param from Include sessions that have started on or after this date. If not specified the start of the current day is used. This value MUST be lesser than the to parameter. @param to Include sessions that have started on or before this date. If not specified the end of the current day is used. This value MUST be greater than the from parameter. @param eTag Used for change detection. A NULL eTag will always fetch the current resource. In subsequent calls set this to the value of the eTag property of the CacheableResource. @return A SessionModel as a CacheableResource @throws NotModifiedException
Implementation
Future<CacheableResource<PagedList<SessionModel>>> listForCohort(DateTime from, DateTime to, Studio studio, {String? etag, PaginationRequest? pagination});