SessionSampleClient class abstract

Constructors

SessionSampleClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

listAccelerationSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<AccelerationSampleModel>>>
Retrieve a user's acceleration samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listActiveEnergyBurnedSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<ActiveEnergyBurnedSampleModel>>>
Retrieve a users's active energy burned samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listBasalEnergyBurnedSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<BasalEnergyBurnedSampleModel>>>
Retrieve a user's basal energy burned samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listCadenceSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<CadenceSampleModel>>>
Retrieve a user's cadence samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listDistanceSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<DistanceSampleModel>>>
Retrieve a user's distance samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listExerciseTimeSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<ExerciseTimeSampleModel>>>
Retrieve a user's exercise time samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listGyroSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<GyroSampleModel>>>
Retrieve a user's gyro samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listHeartRateSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<HeartRateSampleModel>>>
Retrieve a user's heart rate samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listHeartRateSummarySamplesByInterval(int id, {int? userId, int? intervalInSeconds, DateTime? ifModifiedSince}) Future<CacheableResource<List<HeartRateSummarySampleModel>>>
Retrieve a user's heart rate summary samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listHeartRateVariabilitySamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<HeartRateVariabilitySampleModel>>>
Retrieve a user's heart rate variability samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listLocationSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<LocationSampleModel>>>
Retrieve a user's location samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listMagneticFieldSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<MagneticFieldSampleModel>>>
Retrieve a user's magnetic field samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listOxygenSaturationSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<OxygenSaturationSampleModel>>>
Retrieve a user's oxygen saturation samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listPowerSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<PowerSampleModel>>>
Retrieve a user's power samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listRestingHeartRateSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<RestingHeartRateSampleModel>>>
Retrieve a user's resting heart rate samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
listStepSamples(int id, {int? userId, DateTime? ifModifiedSince}) Future<CacheableResource<List<StepSampleModel>>>
Retrieve a user's step samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited