listRestingHeartRateSamples abstract method

Future<CacheableResource<List<RestingHeartRateSampleModel>>> listRestingHeartRateSamples(
  1. int id, {
  2. int? userId,
  3. DateTime? ifModifiedSince,
})

Retrieve a user's resting heart rate samples for the given session id. A null userId defaults to the currently authenticated user. If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.

ifModifiedSince is used for change detection. Send the latest ifModifiedSince returned by the CacheableResource, or NULL to always refresh the data.

Returns a List&lt;RestingHeartRateSampleModel&gt; as a CacheableResource.

Throws NotModifiedException if no change was detected.

Implementation

Future<CacheableResource<List<RestingHeartRateSampleModel>>> listRestingHeartRateSamples(int id, {int? userId, DateTime? ifModifiedSince});