getMetrics abstract method
Retrieve a summary of sessions that were started between the from and to dates. The maximum difference between the from and to dates is 31 days.
The eTag is used for change detection. Send the latest eTag returned by the CacheableResource, or NULL to always refresh the data.
Returns a SessionMetricsModel as a CacheableResource.
Throws NotModifiedException if no change was detected.
Implementation
Future<CacheableResource<SessionMetricsModel>> getMetrics({ DateTime? from, DateTime? to, String? eTag });