SourceClient class abstract

Constructors

SourceClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(int id, {DateTime? ifModifiedSince, String? eTag}) Future<CacheableResource<SourceModel>>
Fetches the source for the given id.
list({String? eTag}) Future<CacheableResource<List<SourceModel>>>
Fetches all sources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(int id, {int? priority, bool? isIncluded}) Future<void>
Patches the given source with the given id. Note that sources are created when activities are created so only the priority and isIncluded fields are updatable. Passing a null value for any of the fields will not update them.
patchAll(List<SourcePatchModel> patches) Future<void>
Patches all sources with the given patches.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited