patch abstract method

Future<void> patch(
  1. int id, {
  2. int? priority,
  3. bool? isIncluded,
})

Patches the given source with the given id. Note that sources are created when activities are created so only the priority and isIncluded fields are updatable. Passing a null value for any of the fields will not update them.

Implementation

Future<void> patch(
  int id, {
  int? priority,
  bool? isIncluded,
});