authState property
Stream of AuthState changes. When the user is authenticated, the AuthState will be set to Authenticated with an appropriate accessToken and userId.
Implementation
Stream<AuthState> get authState;
Stream of AuthState changes. When the user is authenticated, the AuthState will be set to Authenticated with an appropriate accessToken and userId.
Stream<AuthState> get authState;