Authenticated class final
Indicates that the user is authenticated.
- Implemented types
- Available extensions
Constructors
- Authenticated(String accessToken, int userId)
-
Creates an authenticated state with the given
accessTokenanduserId.
Properties
- accessToken → String
-
final
- accessToken → String?
-
Available on AuthState, provided by the AuthStateExtensions extension
Returns the accessToken if the AuthState is Authenticated. Returns null otherwise.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isAuthenticated → bool
-
Available on AuthState, provided by the AuthStateExtensions extension
Returns true if the AuthState is Authenticated.no setter - isUnauthenticated → bool
-
Available on AuthState, provided by the AuthStateExtensions extension
Returns true if the AuthState is Unauthenticated.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
final
- userId → int?
-
Available on AuthState, provided by the AuthStateExtensions extension
Returns the userId if the AuthState is Authenticated. Returns null otherwise.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited