Cacheable class abstract

A Cacheable provides a mechanism for caching based on HTTP response headers.

Implementers

Constructors

Cacheable({DateTime? lastModifiedOn, String? eTag})

Properties

eTag String?
The ETag (Entity Tag) of the cacheable. This is retrieved from the ETag HTTP Header.
final
hashCode int
The hash code for this object.
no setterinherited
lastModifiedOn DateTime?
The last time the cacheable was modified. This is retrieved from the Last-Modified HTTP Header.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited