ConfigurationProvider class

Defines the configuration requirements for the NxFit SDK. An implementation of this must be provided when building NxFit.

See also NxFit.build.

Constructors

ConfigurationProvider(String baseUrl, {HttpLoggerLevel httpLoggerLevel = HttpLoggerLevel.none, LogLevel minLogLevel = LogLevel.warn, int connectTimeoutSeconds = 60})

Properties

baseUrl String
The base URL for the NXFit platform service. This should be in the format: {scheme}://{domain}. There should not be a trailing slash.
final
connectTimeoutSeconds int
Specifies the number of seconds to wait before timing out an HTTP request.
final
hashCode int
The hash code for this object.
no setterinherited
httpLoggerLevel HttpLoggerLevel
Use this to help debug communication issues via logging. Depending on the level set, logs the URL, query parameters, headers and body of both the request and response.
final
minLogLevel LogLevel
Specifies the minimum level of log messages that should be processed by the SDK native components (Android & iOS).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited