httpLoggerLevel property

HttpLoggerLevel httpLoggerLevel
final

Use this to help debug communication issues via logging. Depending on the level set, logs the URL, query parameters, headers and body of both the request and response.

Since this may include sensitive information it is HIGHLY recommended that this be set to none for production builds.

Production recommendation : HttpLoggerLevel.none

Development recommendation: HttpLoggerLevel.body

Default: HttpLoggerLevel.none

See also HttpLoggerLevel.

Implementation

final HttpLoggerLevel httpLoggerLevel;