minLogLevel property

LogLevel minLogLevel
final

Specifies the minimum level of log messages that should be processed by the SDK native components (Android & iOS).

The Dart/Flutter components use the logging package and that should be initialized by the consuming app.

This does not affect the httpLoggerLevel which is configured separately.

Implementation

final LogLevel minLogLevel;