ConflictException constructor

ConflictException({
  1. String? url,
  2. String? message,
  3. String? method,
  4. Exception? cause,
})

The request could not be processed because of conflict in the request. One possible cause is when attempting to create (eg POST) something that has already been created.

Implementation

ConflictException({String? url, String? message, String? method, Exception? cause}) : super(409, url: url, message: message, method: method, cause: cause);