NetworkException class

Implemented types
Implementers

Constructors

NetworkException(int statusCode, {String? url, String? message, String? method, Exception? cause})
An exception indicating an HTTP result that is NOT successful.

Properties

cause Exception?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
method String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited