NotModifiedException class

Indicates an HTTP status code of 304 NOT MODIFIED was received.

The server response indicates that the resource has not been modified based on the values for the 'If-None-Match' or 'If-Modified-Since' request headers.

Inheritance

Constructors

NotModifiedException({String? url, String? message, String? method, Exception? cause})
The server response indicates that the resource has not been modified based on the values for the 'If-None-Match' or 'If-Modified-Since' request headers.

Properties

cause Exception?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String?
finalinherited
method String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
finalinherited
url String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited