NotModifiedException constructor

NotModifiedException({
  1. String? url,
  2. String? message,
  3. String? method,
  4. Exception? cause,
})

The server response indicates that the resource has not been modified based on the values for the 'If-None-Match' or 'If-Modified-Since' request headers.

Implementation

NotModifiedException({String? url, String? message, String? method, Exception? cause}) : super(304, url: url, message: message, method: method, cause: cause);