NxFit class abstract

The NxFit abstraction provides all the clients needed to access NxFit services. An NxFit client is a container that provides a set of HTTP calls to the NXFit service. A single call can retrieve single items or a list of items, it can create or update items, or in some cases remove items on the server.

Use the NXFit.build method to build an instance. Each call to NxFit.build returns a new instance so it's recommended that a single instance is used throughout the application.

Clients are used to access data from the NxFit service API via HTTP. Clients are not responsible for caching but can facilitate caching via the CacheableResource that is returned by the client calls that fetch data. The CacheableResource contains eTag and lastModifiedOn properties which are extracted from the HTTP response headers with similar names. These can then be passed into client methods that accept either an eTag or ifModifiedSince parameter on subsequent calls. The eTag value will be set to the If-None-Match header and the ifModifiedSince value will be set to the If-Modified-Since header on the request. Some client calls may only support one of the two cache control parameters, and those that support both will favour the ifModifiedSince parameter.

Constructors

NxFit()

Properties

authProvider AuthProvider
A reference to the AuthProvider used when building the current instance.
no setter
badgeClient BadgeClient
no setter
configurationProvider ConfigurationProvider
no setter
hashCode int
The hash code for this object.
no setterinherited
integrationClient IntegrationClient
no setter
profileClient ProfileClient
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionClient SessionClient
no setter
sessionSampleClient SessionSampleClient
no setter
sessionSummaryClient SessionSummaryClient
no setter
sourceClient SourceClient
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build(ConfigurationProvider configurationProvider, AuthProvider authProvider) NxFit
Builds a concrete implementation of the NxFit abstraction. When the build completes, all the contained clients are fully initialized and ready to use.