NxFitRepositories class abstract
The NXFitRepositories interface provides repositories that work on top of the NXFit clients. This is an optional component of the NxFit SDK and
is intended to provide cached data.
Each repository corresponds to an NxFit client and it provides access to data even when offline. Each call to the NxFit API is cached and subsequent calls will return cached data unless updates are detected. The calls for data return flows which will emit at least once, whether it be cached data or fresh data from the API service. If the cached data was stale and the server provides updated data, a second emission will be made.
Constructors
Properties
- badgeRepo → BadgeRepository
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- nxfit → NxFit
-
no setter
- profileRepo → ProfileRepository
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionRepo → SessionRepository
-
no setter
- sessionSampleRepo → SessionSampleRepository
-
no setter
- sessionSummaryRepo → SessionSummaryRepository
-
no setter
- sourceRepo → SourceRepository
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
build(
NxFit nxfit) → Future< NxFitRepositories> -
Builds a concrete implementation of the
NXFitRepositoriesinterface. This is an async function because it may make network calls or load data from the local database. When the build completes, all the contained repositories are fully initialized and ready to use.