PagedList<E> class

A paged list of items returned from the NXFit API. The items property contains the list of items returned in the current page. The next and previous properties contain the pagination requests for the next and previous pages respectively. If there is no next or previous page, the corresponding property will be null.

Constructors

PagedList(List<E> items, {PaginationRequest? next, PaginationRequest? previous})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<E>
final
next PaginationRequest?
final
previous PaginationRequest?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited