managers library

Classes

ConnectionEvent
This event is triggered whenever a user attempts to connect to a new integration. The event contains the integration identifier and the result of the connection attempt via the connectionCode property.
DisconnectionEvent
This event is triggered whenever a user successfully disconnects from an integration. It includes the integration identifier.
IntegrationsManager
Provides methods to manage the user's integrations with fitness data providers. Connecting a user to an integration means that fitness data from that integration will be synced and made available for this user.

Enums

IntegrationConnectionCode
When the integration connection process completes, a result is provided back. The response can be decoded with the IntegrationsManager.handleAuthorizeResponse method, which will return the result in the form of this enum.