ConnectionEvent class

This event is triggered whenever a user attempts to connect to a new integration. The event contains the integration identifier and the result of the connection attempt via the connectionCode property.

Constructors

ConnectionEvent(String integrationIdentifier, IntegrationConnectionCode connectionCode)

Properties

connectionCode IntegrationConnectionCode
final
hashCode int
The hash code for this object.
no setterinherited
integrationIdentifier String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited