IntegrationConnectionCode enum

When the integration connection process completes, a result is provided back. The response can be decoded with the IntegrationsManager.handleAuthorizeResponse method, which will return the result in the form of this enum.

Inheritance
Available extensions

Values

failure → const IntegrationConnectionCode
const IntegrationConnectionCode(name: "failure")
success → const IntegrationConnectionCode
const IntegrationConnectionCode(name: "success")

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IntegrationConnectionCode>
A constant List of the values in this enum, in order of their declaration.