canHandleAuthorizeResponseFromUrl abstract method

bool canHandleAuthorizeResponseFromUrl(
  1. Uri response
)

Determines if the given URL can be handled by this manager. Typically this is used to check whether a deep linked URL can be handled such as the redirected URL from an integration connect action.

Implementation

bool canHandleAuthorizeResponseFromUrl(Uri response);