integrations property

Stream<List<IntegrationModel>> get integrations

The complete list of integrations for the current user. A sync process may cause an emission of new integrations.

Implementation

Stream<List<IntegrationModel>> get integrations;