refreshIntegrations abstract method
Will sync the user's integrations with the NxFit service. Any new or updated integrations will be emitted by the integrations stream.
Implementation
Future<void> refreshIntegrations();
Will sync the user's integrations with the NxFit service. Any new or updated integrations will be emitted by the integrations stream.
Future<void> refreshIntegrations();