models library

Enums

ActivityType
Indicates the type of activity for a particular session. The String value is used as a unique code by the NXFit API.
DistanceType
HttpLoggerLevel
Determines the level of logging for HTTP requests and response from the NXFit API.
IntegrationAvailability
Period
SessionPrivacy
Studio