value property
The unique code for the enumeration as used by the NXFit API. This is not intended to be displayed to the user.
Implementation
final String value;
The unique code for the enumeration as used by the NXFit API. This is not intended to be displayed to the user.
final String value;