BadgeModel class

Available extensions
Annotations

Constructors

BadgeModel(int id, String title, String description, String imageUrl, double progress, OffsetDateTime? startedOn, OffsetDateTime? endedOn, OffsetDateTime? completedOn)
const

Properties

completedOn → OffsetDateTime?
final
description String
final
endedOn → OffsetDateTime?
final
hasEnded bool

Available on BadgeModel, provided by the BadgeModelExtensions extension

no setter
hashCode int
The hash code for this object.
no setterinherited
id int
final
imageUrl String
final
isComplete bool

Available on BadgeModel, provided by the BadgeModelExtensions extension

no setter
progress double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedOn → OffsetDateTime?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited