DistanceSampleModel class

Annotations

Constructors

DistanceSampleModel({required OffsetDateTime timestamp, required int intervalInSeconds, required Duration activeTime, required double meters, required DistanceType type})
const

Properties

activeTime Duration
final
hashCode int
The hash code for this object.
no setterinherited
intervalInSeconds int
final
meters double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp → OffsetDateTime
final
type DistanceType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited