ExtendedMetadata class

Inheritance
Annotations

Constructors

ExtendedMetadata(OffsetDateTime createdOn, OffsetDateTime updatedOn, SessionPrivacy privacy, {OffsetDateTime? processedOn})
const

Properties

createdOn → OffsetDateTime
finalinherited
hashCode int
The hash code for this object.
no setterinherited
privacy SessionPrivacy
finalinherited
processedOn → OffsetDateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedOn → OffsetDateTime
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited