HeartRateMetrics class

Annotations

Constructors

HeartRateMetrics(double avgBPM, int maxBPM, int minBPM)
const

Properties

avgBPM double
final
hashCode int
The hash code for this object.
no setterinherited
maxBPM int
final
minBPM int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited