HeartRateZoneModel class

Annotations

Constructors

HeartRateZoneModel(int zone, int minBPM, int maxBPM)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxBPM int
final
minBPM int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited