HttpLoggerLevel enum
Determines the level of logging for HTTP requests and response from the NXFit API.
Values
- none → const HttpLoggerLevel
-
No logging
- errorOnly → const HttpLoggerLevel
-
Logs only HTTP errors.
- headers → const HttpLoggerLevel
-
Logs HTTP Headers for both request and response, as well as any errors.
- body → const HttpLoggerLevel
-
Logs the body for the reqest and response, as well as the headers and any errors.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HttpLoggerLevel> - A constant List of the values in this enum, in order of their declaration.