IntegrationAvailability enum
Values
- available → const IntegrationAvailability
-
The integration is available and can be connected.
const IntegrationAvailability("available") -
The integration is not currently available. For Health Connect, the Health Connect app is not currently installed, but needs to be, before this integration can be connected on this device.
const IntegrationAvailability("unavailable") - unsupported → const IntegrationAvailability
-
The integration is not supported on the device. For Health Connect, this means the Health Connect app is not installed and cannot be installed therefore this integration cannot be connected on this device.
const IntegrationAvailability("unsupported")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IntegrationAvailability> - A constant List of the values in this enum, in order of their declaration.