IntegrationModel class

Available extensions
Annotations

Constructors

IntegrationModel({required String identifier, required String displayName, required String logoUrl, required bool isConnected, required IntegrationAvailability availability, required OffsetDateTime? lastModifiedOn})
const

Properties

availability IntegrationAvailability
final
copyWith → _$IntegrationModelCWProxy

Available on IntegrationModel, provided by the $IntegrationModelCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfIntegrationModel.copyWith(...) or instanceOfIntegrationModel.copyWith.fieldName(...).
no setter
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
isConnected bool
final
lastModifiedOn → OffsetDateTime?
final
logoUrl String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited