LocalIntegration class

Annotations

Constructors

LocalIntegration(String identifier, bool isConnected, IntegrationAvailability availability)
const
LocalIntegration.fromJson(Map<String, dynamic> json)
factory

Properties

availability IntegrationAvailability
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
isConnected bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited