PersonalProfileModel class

Annotations

Constructors

PersonalProfileModel({required int id, required int tenantId, required String? referenceId, required String emailAddress, required String givenName, required String familyName, required String imageUrl, required LocalDate dateOfBirth, required List<int> heartRateZoneThresholds})
const

Properties

dateOfBirth → LocalDate
final
emailAddress String
final
familyName String
final
givenName String
final
hashCode int
The hash code for this object.
no setterinherited
heartRateZoneThresholds List<int>
final
id int
final
imageUrl String
final
referenceId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited