PowerMetrics class

Annotations

Constructors

PowerMetrics(double avgPowerInWatts, double maxPowerInWatts, double minPowerInWatts)
const

Properties

avgPowerInWatts double
final
hashCode int
The hash code for this object.
no setterinherited
maxPowerInWatts double
final
minPowerInWatts double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited