SessionMetricsModel class

Annotations

Constructors

SessionMetricsModel({int activityCount = 0, double? avgBPM, int? maxBPM, int? minBPM, int? energyBurnedInKilocalories, int activeTimeInSeconds = 0, int activeTimeGoalInSeconds = 0})
const

Properties

activeTimeGoalInSeconds int
final
activeTimeInSeconds int
final
activityCount int
final
avgBPM double?
final
energyBurnedInKilocalories int?
final
hashCode int
The hash code for this object.
no setterinherited
maxBPM int?
final
minBPM int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited