SessionModel class

Implementers
Annotations

Constructors

SessionModel(int id, {required ActivityType activityType, required Duration activeDuration, required OffsetDateTime startedOnLocal, required OffsetDateTime endedOnLocal, required UserDetails user, required Metadata metadata, int? energyBurnedInKilocalories, double? maximalOxygenConsumption, HeartRateMetrics? heartRateMetrics, SpeedMetrics? speedMetrics, CadenceMetrics? cadenceMetrics, PowerMetrics? powerMetrics, FloorsClimbedMetrics? floorsClimbedMetrics, RespiratoryRateMetrics? respiratoryRateMetrics})
const

Properties

activeDuration Duration
final
activityType ActivityType
final
cadenceMetrics CadenceMetrics?
final
endedOnLocal → OffsetDateTime
final
energyBurnedInKilocalories int?
final
floorsClimbedMetrics FloorsClimbedMetrics?
final
hashCode int
The hash code for this object.
no setterinherited
heartRateMetrics HeartRateMetrics?
final
id int
final
maximalOxygenConsumption double?
final
metadata Metadata
final
powerMetrics PowerMetrics?
final
respiratoryRateMetrics RespiratoryRateMetrics?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speedMetrics SpeedMetrics?
final
startedOnLocal → OffsetDateTime
final
user UserDetails
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited