SourceModel class

Annotations

Constructors

SourceModel(int id, {required String integrationIdentifier, required String? integrationDisplayName, String? deviceName, String? deviceHardwareVersion, String? deviceManufacturer, String? deviceOS, String? appName, String? appIdentifier, required int priority, required bool isIncluded, required DateTime createdOn, DateTime? updatedOn})
const

Properties

appIdentifier String?
final
appName String?
final
createdOn DateTime
final
deviceHardwareVersion String?
final
deviceManufacturer String?
final
deviceName String?
final
deviceOS String?
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
integrationDisplayName String?
final
integrationIdentifier String
final
isIncluded bool
final
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedOn DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited