SessionSummaryRepository class abstract

Constructors

SessionSummaryRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getHeartRateZones({DateTime? from, DateTime? to}) Stream<HeartRateZoneSummariesModel>
Retrieve a heart rate zone summary for sessions that were started between the from and to dates. The maximum difference between the from and to dates is 31 days.
getMetrics({DateTime? from, DateTime? to}) Stream<SessionMetricsModel>
Retrieve a summary of sessions that were started between the from and to dates. The maximum difference between the from and to dates is 31 days.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited