SourceRepository class abstract

Constructors

SourceRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(int id) Stream<SourceModel?>
list() Stream<List<SourceModel>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(int sourceId, {int? priority, bool? isIncluded}) Future<void>
Updates the supplied property for the given source Id.
updateAll(List<SourcePatchModel> patches) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited