getSettings abstract method
Fetches the current user settings. This call supports change detection, however setting both the ifModifiedSince
and eTag to null will always fetch the current resource. If both are set, ifModifiedSince takes precedence.
Returns a ProfileSettingsModel as a CacheableResource
Throws NotModifiedException if no change was detected.
Implementation
Future<CacheableResource<ProfileSettingsModel>> getSettings({ DateTime? ifModifiedSince, String? eTag });