listHeartRateZoneSummariesForUser abstract method
Retrieve the list of heart rate zone summaries associated with a specific session.
@param id The session id @param ifModifiedSince Used for change detection. In subsequent calls set this to the value of the lastModifiedOn property of the CacheableResource. @param eTag Used for change detection. In subsequent calls set this to the value of the eTag property of the CacheableResource. @return A HeartRateZoneSummariesModel as a CacheableResource @throws NotModifiedException
Implementation
Future<CacheableResource<HeartRateZoneSummariesModel>> listHeartRateZoneSummariesForUser(int userId, int id, {DateTime? ifModifiedSince, String? eTag});