Retrieve a user's acceleration samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a users's active energy burned samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's basal energy burned samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's cadence samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's distance samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's exercise time samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's gyro samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's heart rate samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's heart rate summary samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's heart rate variability samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's location samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's magnetic field samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's oxygen saturation samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's power samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's resting heart rate samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
Retrieve a user's step samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.