listRestingHeartRateSamples abstract method
Retrieve a user's resting heart rate samples for the given session id. A null userId defaults to the currently authenticated user.
If intervalInSeconds is provided, the samples will be interpolated to the given number of seconds.
ifModifiedSince is used for change detection. Send the latest ifModifiedSince returned by the CacheableResource, or NULL to always
refresh the data.
Returns a List<RestingHeartRateSampleModel> as a CacheableResource.
Throws NotModifiedException if no change was detected.
Implementation
Future<CacheableResource<List<RestingHeartRateSampleModel>>> listRestingHeartRateSamples(int id, {int? userId, DateTime? ifModifiedSince});