patch abstract method
Patches the given source with the given id. Note that sources are created when activities are created so only the priority
and isIncluded fields are updatable. Passing a null value for any of the fields will not update them.
Implementation
Future<void> patch(
int id, {
int? priority,
bool? isIncluded,
});