CacheableResource<T> class
Encapsulates a resource that can be cached via an eTag and lastModifiedOn. The resource can be any type, however how the resource is cached is up to the caller.
See also Cacheable
Constructors
- CacheableResource(T value, {DateTime? lastModifiedOn, String? eTag})
Properties
- eTag → String?
-
The ETag (Entity Tag) of the cacheable. This is retrieved from the ETag HTTP Header.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastModifiedOn → DateTime?
-
The last time the cacheable was modified. This is retrieved from the Last-Modified HTTP Header.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
The resource to be cached.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited