ConflictException class
Indicates an HTTP status code of 409 CONFLICT was received.
The request could not be processed because of conflict in the request. One possible cause is when attempting to create (eg POST) something that has already been created.
- Inheritance
-
- Object
- NetworkException
- ConflictException
Constructors
- ConflictException({String? url, String? message, String? method, Exception? cause})
- The request could not be processed because of conflict in the request. One possible cause is when attempting to create (eg POST) something that has already been created.
Properties
- cause → Exception?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
finalinherited
- method → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
finalinherited
- url → String?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited