ConflictException constructor
The request could not be processed because of conflict in the request. One possible cause is when attempting to create (eg POST) something that has already been created.
Implementation
ConflictException({String? url, String? message, String? method, Exception? cause}) : super(409, url: url, message: message, method: method, cause: cause);