PaginationRequest class
Constructors
- PaginationRequest(int limit)
- PaginationRequest.next(int limit, String? afterToken)
- PaginationRequest.previous(int limit, String? beforeToken)
Properties
- afterToken → String?
-
final
- beforeToken → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited