UnauthorizedException class
Indicates an HTTP status code of 401 UNAUTHORIZED was received.
Current user has not been authenticated and has attempted to access protected resources. Perhaps the user needs to authenticate.
- Inheritance
-
- Object
- NetworkException
- UnauthorizedException
Constructors
- Current user has not been authenticated and has attempted to access protected resources. Perhaps the user needs to authenticate.
Properties
- cause → Exception?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
finalinherited
- method → String?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
finalinherited
- url → String?
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited