SessionRepository class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
int id) → Stream< UserSessionModel> -
getForUser(
int userId, int id) → Stream< UserSessionModel> -
list(
{DateTime? from, DateTime? to}) → Stream< List< UserSessionModel> > -
listForCohort(
DateTime from, DateTime to, Studio studio, {PaginationRequest? pagination}) → Stream< PagedList< SessionModel> > -
listHeartRateZoneSummaries(
int id) → Stream< HeartRateZoneSummariesModel> -
listHeartRateZoneSummariesForUser(
int userId, int id) → Stream< HeartRateZoneSummariesModel> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited