Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listAccelerationSamples(int id, {int? userId})
→ Stream<List<AccelerationSampleModel>>
-
Retrieve a user's acceleration samples for the given session id. A null userId defaults to the currently authenticated user.
-
listActiveEnergyBurnedSamples(int id, {int? userId})
→ Stream<List<ActiveEnergyBurnedSampleModel>>
-
Retrieve a users's active energy burned samples for the given session id. A null userId defaults to the currently authenticated user.
-
listBasalEnergyBurnedSamples(int id, {int? userId})
→ Stream<List<BasalEnergyBurnedSampleModel>>
-
Retrieve a user's basal energy burned samples for the given session id. A null userId defaults to the currently authenticated user.
-
listCadenceSamples(int id, {int? userId})
→ Stream<List<CadenceSampleModel>>
-
Retrieve a user's cadence samples for the given session id. A null userId defaults to the currently authenticated user.
-
listDistanceSamples(int id, {int? userId})
→ Stream<List<DistanceSampleModel>>
-
Retrieve a user's distance samples for the given session id. A null userId defaults to the currently authenticated user.
-
listExerciseTimeSamples(int id, {int? userId})
→ Stream<List<ExerciseTimeSampleModel>>
-
Retrieve a user's exercise time samples for the given session id. A null userId defaults to the currently authenticated user.
-
listGyroSamples(int id, {int? userId})
→ Stream<List<GyroSampleModel>>
-
Retrieve a user's gyro samples for the given session id. A null userId defaults to the currently authenticated user.
-
listHeartRateSamples(int id, {int? userId})
→ Stream<List<HeartRateSampleModel>>
-
Retrieve a user's heart rate samples for the given session id. A null userId defaults to the currently authenticated user.
-
listHeartRateSummarySamplesByInterval(int id, {int? userId, int? intervalInSeconds})
→ Stream<List<HeartRateSummarySampleModel>>
-
Retrieve a user's heart rate summary samples for the given session id. A null userId defaults to the currently authenticated user.
-
listHeartRateVariabilitySamples(int id, {int? userId})
→ Stream<List<HeartRateVariabilitySampleModel>>
-
Retrieve a user's heart rate variability samples for the given session id. A null userId defaults to the currently authenticated user.
-
listLocationSamples(int id, {int? userId})
→ Stream<List<LocationSampleModel>>
-
Retrieve a user's location samples for the given session id. A null userId defaults to the currently authenticated user.
-
listMagneticFieldSamples(int id, {int? userId})
→ Stream<List<MagneticFieldSampleModel>>
-
Retrieve a user's magnetic field samples for the given session id. A null userId defaults to the currently authenticated user.
-
listOxygenSaturationSamples(int id, {int? userId})
→ Stream<List<OxygenSaturationSampleModel>>
-
Retrieve a user's oxygen saturation samples for the given session id. A null userId defaults to the currently authenticated user.
-
listPowerSamples(int id, {int? userId})
→ Stream<List<PowerSampleModel>>
-
Retrieve a user's power samples for the given session id. A null userId defaults to the currently authenticated user.
-
listRestingHeartRateSamples(int id, {int? userId})
→ Stream<List<RestingHeartRateSampleModel>>
-
Retrieve a user's resting heart rate samples for the given session id. A null userId defaults to the currently authenticated user.
-
listStepSamples(int id, {int? userId})
→ Stream<List<StepSampleModel>>
-
Retrieve a user's step samples for the given session id. A null userId defaults to the currently authenticated user.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited